import * as _nuxt_schema from '@nuxt/schema';
import { VisualEditingOptions as VisualEditingOptions$1, HistoryRefresh } from '@sanity/visual-editing';
import { ClientConfig } from '@sanity/client';
import { Slug, ImageAsset, PortableTextBlock } from '@sanity/types';

type ModuleOptions = ClientConfig & {
    projectId?: string;
    /** @default "production" */
    dataset?: string;
    /** @default { cachingEnabled: true, cacheBaseUrl: "http://localhost:3000", assetEndpoint: "/_sanity/cache/asset", queryEndpoint: "/_sanity/cache/query", webhookEndpoint: "/_sanity/cache/invalidate" } */
    minimalClient?: boolean | {
        cachingEnabled?: boolean;
        /**
         * This is the base url for fetching data after hydration
         * @default 'http://localhost:3000'
         */
        cacheClientBaseUrl?: string;
        /**
         * This is the base url for fetching data during SSR
         * @default 'http://localhost:3000'
         */
        cacheServerBaseUrl?: string;
        assetEndpoint?: string;
        queryEndpoint?: string;
        webhookEndpoint?: string;
        webhookSecret?: string;
    };
    /** @default true */
    useCdn?: boolean;
    /** @default "2024-08-08" */
    apiVersion?: string;
    visualEditing?: VisualEditingOptions;
};
interface VisualEditingOptions {
    /** @default { enableEndpoint: "/_sanity/preview/enable", disableEndpoint: "/_sanity/preview/disable" } */
    previewMode?: boolean | {
        enableEndpoint?: string;
        disableEndpoint?: string;
    };
    previewModeId?: string;
    /** @default "live-visual-editing" */
    mode?: SanityVisualEditingMode;
    /** @default "/_sanity/fetch" */
    proxyEndpoint?: string;
    token?: string;
    studioUrl?: string;
    /** @default true */
    stega?: boolean;
    /** This function is only required if `mode` is set to 'visual-editing' */
    refresh?: SanityVisualEditingRefreshHandler;
    /** @default 100 */
    zIndex?: VisualEditingOptions$1['zIndex'];
}
type SanityVisualEditingMode = 'live-visual-editing' | 'visual-editing' | 'custom';
type SanityVisualEditingRefreshHandler = (payload: HistoryRefresh, refreshDefault: () => false | Promise<void>) => false | Promise<void>;

interface Page {
    _id: string;
    _type: 'page';
    title: string;
    slug: Slug;
    modules: SanityArray<SanityModule>;
    seo: SEO;
}

interface GlobalSEO {
    siteName: string;
    image: {
        asset: ImageAsset;
    };
}

interface LinkExternal {
    _type: 'linkExternal';
    url: string;
    newWindow: boolean;
    linkTitle?: string;
    relationship?: string;
}

interface LinkInternal {
    _type: 'linkInternal';
    slug: string;
    linkTitle?: string;
    relationship?: string;
}

interface SEO {
    _type: 'seo';
    indexable: boolean;
    priority: number;
    changeFreq: 'always' | 'daily' | 'weekly' | 'monthly' | 'yearly' | 'never';
    title: string;
    shortTitle: string;
    description: string;
    image?: {
        asset: ImageAsset;
    };
}

type RichText = PortableTextBlock[];

interface Home {
    _type: 'home';
    modules: SanityArray<SanityModule>;
    seo: SEO;
}

interface NotFound {
    _type: 'notFound';
    modules: SanityArray<SanityModule>;
    seo: SEO;
}

type SanityModule = {
    _type?: string;
};

type SanityArray<T> = Array<T & {
    _key: string;
}>;

declare const _default: _nuxt_schema.NuxtModule<ModuleOptions, ModuleOptions, false>;

export { _default as default };
export type { GlobalSEO, Home, LinkExternal, LinkInternal, ModuleOptions, NotFound, Page, RichText, SEO, SanityArray, SanityModule, SanityVisualEditingMode, SanityVisualEditingRefreshHandler, VisualEditingOptions };
