import {
  createClient
} from "@sanity/client";
import { createQueryStore as createCoreQueryStore } from "@sanity/core-loader";
import { SanityClient } from "#imports";
class DefaultSanityClient extends SanityClient {
  client;
  queryStore = null;
  constructor(config) {
    super(config);
    this.client = createClient(config);
  }
  async fetch(query, params, options) {
    try {
      return await this.client.fetch(query, params, options);
    } catch (error) {
      console.error("Failed to fetch data from Sanity:", error);
      return null;
    }
  }
  createQueryStore(tag) {
    const queryStore = createCoreQueryStore({
      tag: tag || "nuxt-loader",
      client: false,
      ssr: true
    });
    if (import.meta.server) {
      const serverClient = this.client.withConfig({
        perspective: "drafts",
        token: this.config.token,
        useCdn: false
      });
      queryStore.setServerClient(serverClient);
    }
    this.queryStore = queryStore;
  }
  clone() {
    return new DefaultSanityClient({
      useCdn: this.config.useCdn,
      projectId: this.config.projectId,
      dataset: this.config.dataset,
      apiVersion: this.config.apiVersion,
      withCredentials: this.config.withCredentials,
      token: this.config.token,
      perspective: this.config.perspective
    });
  }
}
export default DefaultSanityClient;
