import { hash } from "ohash";
import { useAsyncData, useLazyAsyncData } from "nuxt/app";
import { reactive, ref } from "vue";
import defu from "defu";
import useSanityClient from "../utils/useSanityClient.js";
import { useSanityVisualEditingState } from "./useSanityVisualEditingState.js";
import { useRuntimeConfig } from "#imports";
export function useLazySanityQuery(query, params = {}, options = {}) {
  return useSanityQuery(query, params, options, true);
}
export function useSanityQuery(query, _params = {}, options = {}, lazy = false) {
  const $config = useRuntimeConfig();
  const sanityConfig = defu(import.meta.server ? $config.sanity : {}, $config.public.sanity);
  const visualEditingEnabled = useSanityVisualEditingState().enabled;
  const clientType = visualEditingEnabled ? "default" : options.client || (sanityConfig.minimalClient ? "minimal" : "default");
  const perspective = options.perspective || (visualEditingEnabled ? "drafts" : "published");
  const reactiveParams = _params ? reactive(_params) : void 0;
  if (reactiveParams) {
    options.watch ||= [];
    options.watch.push(reactiveParams);
  }
  const data = ref(null);
  const sourceMap = ref(null);
  const encodeDataAttribute = ref(() => {
  });
  function updateRefs(resultData, resultSourceMap, resultEncodeDataAttribute) {
    data.value = resultData;
    sourceMap.value = resultSourceMap || null;
    if (resultEncodeDataAttribute) encodeDataAttribute.value = resultEncodeDataAttribute;
  }
  const fetchFunc = () => new Promise((resolve) => {
    (visualEditingEnabled ? import("../utils/visualEditing/fetchSanityData") : import("../utils/default/fetchSanityData")).then(async ({ fetchSanityData }) => {
      const client = import.meta.server ? (await import("../server/utils/useSanityClient.js")).default(clientType, sanityConfig) : await useSanityClient(visualEditingEnabled, clientType, sanityConfig);
      function onDataUpdate(resultData, resultSourceMap, resultEncodeDataAttribute) {
        if (resultEncodeDataAttribute)
          encodeDataAttribute.value = resultEncodeDataAttribute;
        resolve({ data: resultData, sourceMap: resultSourceMap });
      }
      const fetchSanityDataFunc = fetchSanityData;
      fetchSanityDataFunc(query, reactiveParams, client, perspective, onDataUpdate);
    });
  });
  const key = "sanity-" + hash(query + (reactiveParams ? JSON.stringify(reactiveParams) : ""));
  const pendingData = lazy ? useLazyAsyncData(key, fetchFunc, options) : useAsyncData(key, fetchFunc, options);
  if (visualEditingEnabled && import.meta.client) {
    import("../utils/visualEditing/subscribeToChanges.js").then(async ({ subscribeToChanges }) => {
      const client = await useSanityClient(visualEditingEnabled, clientType, sanityConfig);
      subscribeToChanges(query, reactiveParams, client, updateRefs);
    });
  }
  return Object.assign(new Promise((resolve) => pendingData.then(({ data: { value } }) => {
    updateRefs(value.data, value.sourceMap);
    resolve({ ...pendingData, data, sourceMap, encodeDataAttribute });
  })), { ...pendingData, data, sourceMap, encodeDataAttribute });
}
