import { enableVisualEditing as enableSanityVisualEditing } from "@sanity/visual-editing";
import { reloadNuxtApp, useRouter } from "#imports";
export function enableVisualEditing(options = {}) {
  const { refresh, zIndex } = options;
  let disable = () => {
  };
  if (import.meta.client) {
    const router = useRouter();
    disable = enableSanityVisualEditing({
      zIndex,
      refresh: (payload) => {
        function refreshDefault() {
          if (payload.source === "mutation" && payload.livePreviewEnabled)
            return false;
          return new Promise((resolve) => {
            reloadNuxtApp({ ttl: 1e3 });
            resolve();
          });
        }
        return refresh ? refresh(payload, refreshDefault) : refreshDefault();
      },
      history: {
        subscribe(navigate) {
          router.isReady().then(() => navigate({ type: "replace", url: router.currentRoute.value.fullPath }));
          return router.afterEach((to) => navigate({ type: "push", url: to.fullPath }));
        },
        update(update) {
          switch (update.type) {
            case "push":
            case "replace":
              router[update.type](update.url);
              break;
            case "pop":
              router.back();
              break;
          }
        }
      }
    });
  }
  return disable;
}
